/**
 * @file cw32l010_i2c.h
 * @author WHXY
 * @brief
 * @version 0.1
 * @date 2024-08-07
 *
 * @copyright Copyright (c) 2021
 * x
 */

/*******************************************************************************
*
* 代码许可和免责信息
* 武汉芯源半导体有限公司授予您使用所有编程代码示例的非专属的版权许可，您可以由此
* 生成根据您的特定需要而定制的相似功能。根据不能被排除的任何法定保证，武汉芯源半
* 导体有限公司及其程序开发商和供应商对程序或技术支持（如果有）不提供任何明示或暗
* 含的保证或条件，包括但不限于暗含的有关适销性、适用于某种特定用途和非侵权的保证
* 或条件。
* 无论何种情形，武汉芯源半导体有限公司及其程序开发商或供应商均不对下列各项负责，
* 即使被告知其发生的可能性时，也是如此：数据的丢失或损坏；直接的、特别的、附带的
* 或间接的损害，或任何后果性经济损害；或利润、业务、收入、商誉或预期可节省金额的
* 损失。
* 某些司法辖区不允许对直接的、附带的或后果性的损害有任何的排除或限制，因此某些或
* 全部上述排除或限制可能并不适用于您。
*
*******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __CW32L010_I2C_H
#define __CW32L010_I2C_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "system_cw32l010.h"

#define I2C_TIMEOUT        1000    // HCLK为8MHz时，超时约1000us，其他频率可以类推
/**
 * @brief  I2C通道选择
 *
 */
typedef enum en_i2c_channel
{
    I2C1 = 0,///<通道1
    I2C2 = 1,///<通道2
} en_i2c_channel_t;

typedef enum 
{
    I2C_NO_ERROR = 0,                         // Error type codes
	I2C_MT_ARBITRATION_LOST,              // A
	I2C_MR_ARBITRATION_LOST,              // B
	I2C_ARBITRATION_LOST_AND_ST_SELECTED, // C
	I2C_ARBITRATION_LOST_AND_SR_SELECTED, // D
	I2C_MT_ADDR_NACK,                     // E
	I2C_MT_DATA_NACK,                     // F
	I2C_MR_ADDR_NACK,                     // G
	I2C_MR_DATA_NACK,                     // H
	I2C_ST_DATA_NACK,                     // I
	I2C_SR_DATA_NACK,                     // J
	I2C_SR_STOP,                          // K
	I2C_BUS_ERROR,                        // L
    I2C_BUSY    
}I2C_ErrorDef;
/**
 ******************************************************************************
 ** \brief I2C初始化配置结构
 *****************************************************************************/
typedef struct
{
    uint32_t                PCLK_Freq;     // PCLK时钟频率，如8000000Hz
    uint32_t                I2C_SCL_Freq;  // I2C时钟频率，如400000Hz
    uint32_t                I2C_SDA_Source;    // SDA来源
    uint32_t                I2C_SCL_Source;    // SCL来源
    uint8_t                 I2C_OwnSlaveAddr0;   ///<从机地址0    
    uint8_t                 I2C_OwnSlaveAddr1;   ///<从机地址1
    uint8_t                 I2C_OwnSlaveAddr2;   ///<从机地址2
    FunctionalState         I2C_OwnGc;   ///<广播响应使能
}I2C_InitTypeDef;

/** @defgroup I2C_Exported_Constants
 * @{
 */
#define IS_I2C_ALL_PERIPH(PERIPH)               ((PERIPH) == CW_I2C1)
                                                 
#define IS_I2C_OWN_ADDRESS0(ADDRESS0)           ((ADDRESS0) <= 0x7F)
#define IS_I2C_OWN_ADDRESS1(ADDRESS1)           ((ADDRESS1) <= 0x7F)
#define IS_I2C_OWN_ADDRESS2(ADDRESS2)           ((ADDRESS2) <= 0x7F)

#define IS_I2C_SCL_FREQ(FREQ)           ((FREQ) <= 1000000ul)
#define IS_I2C_Baud_BRR(BRR)            ((BRR) >0 && (BRR) <= 0xFF)


#define I2C_SDA_SRC_GPIO                (0UL << I2Cx_CR_SDAINSRC_Pos)
#define I2C_SDA_SRC_VC1_OUT             (1UL << I2Cx_CR_SDAINSRC_Pos)
#define I2C_SDA_SRC_VC2_OUT             (2UL << I2Cx_CR_SDAINSRC_Pos)

#define I2C_SCL_SRC_GPIO                (0UL << I2Cx_CR_SCLINSRC_Pos)
#define I2C_SCL_SRC_VC1_OUT             (1UL << I2Cx_CR_SCLINSRC_Pos)
#define I2C_SCL_SRC_VC2_OUT             (2UL << I2Cx_CR_SCLINSRC_Pos)

/** @defgroup I2C_transfer_direction
  * @{
  */

#define I2C_Direction_Transmitter               ((uint8_t)0x00)
#define I2C_Direction_Receiver                  ((uint8_t)0x01)
#define IS_I2C_DIRECTION(DIRECTION)             (((DIRECTION) == I2C_Direction_Transmitter) || \
                                                 ((DIRECTION) == I2C_Direction_Receiver))

//设置波特率配置寄存器
void I2C_SetBaud(I2C_TypeDef *I2Cx, uint8_t u8TBaud);
//发送START信号
void I2C_GenerateSTART(I2C_TypeDef *I2Cx, FunctionalState NewState);
//发送STOP信号
void I2C_GenerateSTOP(I2C_TypeDef *I2Cx);
//Ack信号配置
void I2C_AcknowledgeConfig(I2C_TypeDef *I2Cx, FunctionalState NewState);
//Filter配置
void I2C_FilterConfig(I2C_TypeDef *I2Cx, FunctionalState NewState);
//做从机时的从机地址0配置
void I2C_SetOwnSlaveAddress0(I2C_TypeDef *I2Cx, uint8_t I2CSlaveAddr);
//做从机时的从机地址1配置
void I2C_SetOwnSlaveAddress1(I2C_TypeDef *I2Cx, uint8_t I2CSlaveAddr);
//做从机时的从机地址2配置
void I2C_SetOwnSlaveAddress2(I2C_TypeDef *I2Cx, uint8_t I2CSlaveAddr);
//做从机时广播响应配置
void I2C_GcConfig(I2C_TypeDef *I2Cx, FunctionalState NewState);
//I2C模块使能
void I2C_Cmd(I2C_TypeDef *I2Cx, FunctionalState NewState);
//获取SI中断标志
ITStatus I2C_GetIrq(I2C_TypeDef *I2Cx);
//清除SI中断标志
void I2C_ClearIrq(I2C_TypeDef *I2Cx);
//获取状态寄存器
uint8_t I2C_GetState(I2C_TypeDef *I2Cx);
//I2C MASTER初始化
void I2C_Master_Init(I2C_TypeDef *I2Cx, I2C_InitTypeDef *I2C_InitStruct);
//I2C SLAVE初始化
void I2C_Slave_Init(I2C_TypeDef *I2Cx, I2C_InitTypeDef *I2C_InitStruct);
//I2C1关闭初始化
void I2C1_DeInit(void);
//I2C2关闭初始化
void I2C2_DeInit(void);
//发送1字节数据
void I2C_SendData(I2C_TypeDef *I2Cx, uint8_t Data);
//接收1字节数据
uint8_t I2C_ReceiveData(I2C_TypeDef *I2Cx);
//发送地址字节
void I2C_Send7bitAddress(I2C_TypeDef *I2Cx, uint8_t Address, uint8_t I2C_Direction);
//软复位I2C1模块
void I2C1_SoftwareResetCmd(FunctionalState NewState);
//软复位I2C2模块
void I2C2_SoftwareResetCmd(FunctionalState NewState);
//主发送数据
I2C_ErrorDef I2C_MasterSendDataToSlave(I2C_TypeDef* I2Cx,uint8_t u8SlaveAddr, uint8_t* pu8Data, uint32_t u32Len);
//主接收数据
I2C_ErrorDef I2C_MasterRecDataFromSlave(I2C_TypeDef* I2Cx,uint8_t u8SlaveAddr, uint8_t* pu8Data, uint32_t u32Len);
//从发送数据
I2C_ErrorDef I2C_SlaveSendDataToMaster(I2C_TypeDef *I2Cx, uint8_t *pu8Data, uint32_t u32Len);
//从接收数据
I2C_ErrorDef I2C_SlaveRecDataFromMaster(I2C_TypeDef *I2Cx, uint8_t *pu8Data, uint32_t *pu32Len);

//从机状态检测
uint8_t I2C_MasterCheckSlaveBusy(I2C_TypeDef *I2Cx);


//禁止I2C的中断
void I2C_DisableInt(I2C_TypeDef *I2Cx);
//使能I2C的中断
void I2C_EnableInt(I2C_TypeDef *I2Cx);

#ifdef __cplusplus
}
#endif

#endif /*__CW32L010_I2C_H */
